@@ -23,7 +23,7 @@ except:
     from Crypto.Cipher import AES # https://www.dlitz.net/software/pycrypto/
 
 
-__version__ = '0.9.923'
+__version__ = '0.9.925'
 
 module_logger = logging.getLogger(__name__)
 
@@ -116,7 +116,7 @@ class iOSbackup(object):
 
     platformFoldersHint = {
         'darwin': '~/Library/Application Support/MobileSync/Backup',
-        'win32': r'%HOME%\Apple Computer\MobileSync\Backup'
+        'win32': r'%APPDATA%\Apple Computer\MobileSync\Backup'
     }
 
     catalog = {
